Method: Buby#createTextEditor

Defined in:
lib/buby.rb

#createTextEditorITextEditor Also known as: create_text_editor

This method is used to create a new instance of Burp’s plain text editor, for the extension to use in its own UI.

Returns:

  • (ITextEditor)

    A new text editor the extension can use in its own UI.



1566
1567
1568
# File 'lib/buby.rb', line 1566

def createTextEditor
  _check_and_callback(:createTextEditor)
end